@@ -60,7 +60,7 @@ Net::XMPP::Client - XMPP Client Module
     $Con->Execute(hostname=>"jabber.org",
                   username=>"bob",
                   password=>"XXXX",
-                  resource=>"Work'
+                  resource=>"Work"
                  );
 
     #
@@ -86,9 +86,9 @@ Net::XMPP::Client - XMPP Client Module
             port=>integer,           listed in the hostname (default
             timeout=>int             localhost), on the port (default
             connectiontype=>string,  5222) listed, using the
-            tls=>0|1)                connectiontype listed (default
-                                     tcpip).  The two connection types
-                                     available are:
+            tls=>0|1,                connectiontype listed (default
+            srv=>0|1,                tcpip).  The two connection types
+            componentname=>string)   available are:
                                        tcpip  standard TCP socket
                                        http   TCP socket, but with the
                                               headers needed to talk
@@ -97,6 +97,20 @@ Net::XMPP::Client - XMPP Client Module
                                      will be used if it is available
                                      as a feature.
 
+                                     If srv is specified AND Net::DNS is
+                                     installed and can be loaded, then
+                                     an SRV query is sent to srv.hostname
+                                     and the results processed to replace
+                                     the hostname and port.  If the lookup
+                                     fails, or Net::DNS cannot be loaded,
+                                     then hostname and port are left alone
+                                     as the defaults.
+                                     
+                                     Alternatively, you may manually specify
+                                     componentname as the domain portion of the
+                                     jid and leave hostname set to the actual
+                                     hostname of the XMPP server.
+
     Execute(hostname=>string,       - Generic inner loop to handle
             port=>int,                connecting to the server, calling
             tls=>0|1,                 Process, and reconnecting if the
@@ -142,7 +156,7 @@ Net::XMPP::Client - XMPP Client Module
                                       Client will attempt to register the
                                       sepecified account for you, if it
                                       does not exist.
-            
+
     Process(integer) - takes the timeout period as an argument.  If no
                        timeout is listed then the function blocks until
                        a packet is received.  Otherwise it waits that
@@ -156,7 +170,7 @@ Net::XMPP::Client - XMPP Client Module
                            1   - Status ok, data received.
                            0   - Status ok, no data received.
                          undef - Status not ok, stop processing.
-                       
+
                        IMPORTANT: You need to check the output of every
                        Process.  If you get an undef then the connection
                        died and you should behave accordingly.
@@ -168,12 +182,16 @@ Net::XMPP::Client - XMPP Client Module
 
 =head1 AUTHOR
 
-Ryan Eatmon
+Originally authored by Ryan Eatmon.
+
+Previously maintained by Eric Hacker. 
+
+Currently maintained by Darian Anthony Patrick.
 
 =head1 COPYRIGHT
 
-This module is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This module is free software, you can redistribute it and/or modify it
+under the LGPL 2.1.
 
 =cut
 
@@ -189,7 +207,7 @@ sub new
 
     bless($self, $proto);
     $self->init(@_);
-    
+
     $self->{SERVER}->{port} = 5222;
     $self->{SERVER}->{namespace} = "jabber:client";
     $self->{SERVER}->{allow_register} = 1;
@@ -209,7 +227,7 @@ sub _auth
     $auth{username} = $args{username};
     $auth{password} = $args{password};
     $auth{resource} = $args{resource} if exists($args{resource});
-    
+
     return $self->AuthSend(%auth);
 }
 
@@ -218,7 +236,7 @@ sub _connection_args
 {
     my $self = shift;
     my (%args) = @_;
-    
+
     my %connect;
     $connect{hostname}       = $args{hostname};
     $connect{port}           = $args{port}           if exists($args{port});
